from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import (
    BaseResourceCheck, CheckResult)


class CVMUserData(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Tencent Cloud CVM user data does not contain sensitive information"
        id = "CKV_TC_13"
        supported_resources = ['tencentcloud_instance']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: dict) -> CheckResult:
        if conf.get("user_data_raw") and ("TENCENTCLOUD_SECRET_ID" in conf["user_data_raw"][0] or "TENCENTCLOUD_SECRET_KEY" in conf["user_data_raw"][0]):
            return CheckResult.FAILED
        if conf.get("user_data") and ("TENCENTCLOUD_SECRET_ID" in conf["user_data"][0] or "TENCENTCLOUD_SECRET_KEY" in conf["user_data"][0]):
            return CheckResult.FAILED
        return CheckResult.PASSED


check = CVMUserData()



from __future__ import annotations
from typing import Any
from checkov.arm.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class SynapseWorkspaceCMKEncryption(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure Azure Synapse Workspace is encrypted with a CMK"
        id = "CKV_AZURE_240"
        supported_resources = ['Microsoft.Synapse/workspaces']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
        encryption = conf.get("properties", {}).get("encryption", {})

        if "cmk" in encryption:
            return CheckResult.PASSED

        return CheckResult.FAILED


check = SynapseWorkspaceCMKEncryption()



from typing import Any

from checkov.common.models.enums import CheckCategories
from checkov.arm.base_resource_value_check import BaseResourceValueCheck


class KeyVaultEnablesPurgeProtection(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that key vault enables purge protection"
        id = "CKV_AZURE_110"
        supported_resources = ['Microsoft.KeyVault/vaults']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> Any:
        return "properties/enablePurgeProtection"

    def get_expected_value(self) -> bool:
        return True


check = KeyVaultEnablesPurgeProtection()



from __future__ import annotations

from typing import Any

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.arm.base_resource_check import BaseResourceCheck


class AzureSearchSQLQueryUpdates(BaseResourceCheck):
    def __init__(self) -> None:
        # Cognitive Search services support indexing and querying. Indexing is the process of loading content
        # into the service to make it searchable. Querying is the process where a client searches for content
        # by sending queries to the index.
        # Cognitive Search supports a configurable number of replicas.
        # Having multiple replicas allows queries and index updates to load balance across multiple replicas.
        # To receive a Service Level Agreement (SLA) for Search index queries a minimum of 2 replicas is required.
        name = "Ensure that Azure Cognitive Search maintains SLA for search index queries"
        id = "CKV_AZURE_209"
        supported_resources = ["Microsoft.Search/searchServices", ]
        categories = [CheckCategories.GENERAL_SECURITY, ]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
        self.evaluated_keys = ["properties/replicaCount"]

        properties = conf.get("properties", {})
        if not isinstance(properties, dict):
            return CheckResult.FAILED
        replica_count = properties.get("replicaCount")
        if replica_count:
            if not isinstance(replica_count, int):
                return CheckResult.UNKNOWN
            if replica_count >= 2:
                return CheckResult.PASSED

        return CheckResult.FAILED


check = AzureSearchSQLQueryUpdates()



from typing import Dict, Any

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.common.util.type_forcers import force_list
from checkov.arm.base_resource_check import BaseResourceCheck


class FrontDoorWAFACLCVE202144228(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure Front Door WAF prevents message lookup in Log4j2. See CVE-2021-44228 aka log4jshell"
        id = "CKV_AZURE_133"
        supported_resources = ["Microsoft.Network/frontdoorWebApplicationFirewallPolicies"]
        categories = [CheckCategories.APPLICATION_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[Any, Any]) -> CheckResult:
        self.evaluatedKeys = ["managedRules"]
        properties = conf.get("properties")
        if properties is None or "managedRules" not in properties:
            return CheckResult.FAILED

        managedRules = properties.get("managedRules")
        if not managedRules:
            return CheckResult.FAILED

        for idx_managed_rule, managed_rule in enumerate(force_list(managedRules.get("managedRuleSets", []))):
            self.evaluated_keys = [f"managedRules/[{idx_managed_rule}]/type"]
            if managed_rule and managed_rule.get("ruleSetType") in ["DefaultRuleSet", "Microsoft_DefaultRuleSet"]:
                ruleOverrides = managed_rule.get("ruleGroupOverrides", [])
                if ruleOverrides == []:
                    return CheckResult.PASSED
                for idx_override, rule_override in enumerate(force_list(ruleOverrides)):
                    self.evaluated_keys.append(
                        f"managedRules/[{idx_managed_rule}]/ruleGroupOverrides/[{idx_override}]/ruleGroupName"
                    )
                    if rule_override.get("ruleGroupName") == "JAVA":
                        rules = rule_override.get("rules", [])
                        for idx_rule, rule in enumerate(force_list(rules)):
                            self.evaluated_keys.extend([
                                f"managedRules/[{idx_managed_rule}]/ruleGroupOverrides/[{idx_override}]/rules/[{idx_rule}]/ruleId",
                                f"managedRules/[{idx_managed_rule}]/ruleGroupOverrides/[{idx_override}]/rules/[{idx_rule}]/enabledState",
                                f"managedRules/[{idx_managed_rule}]/ruleGroupOverrides/[{idx_override}]/rules/[{idx_rule}]/action",
                            ])
                            if rule.get("ruleId") == "944240":
                                enabledState = rule.get("enabledState")
                                if not enabledState:
                                    return CheckResult.FAILED
                                if rule.get("action") in ["Block", "Redirect"]:
                                    return CheckResult.PASSED

        return CheckResult.FAILED


check = FrontDoorWAFACLCVE202144228()



from typing import Any, List

from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import \
    BaseResourceValueCheck


class CBSEncryption(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure Tencent Cloud CBS is encrypted"
        id = "CKV_TC_1"
        supported_resources = ['tencentcloud_cbs_storage']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'encrypt'

    def get_expected_value(self) -> List[Any]:
        return True


check = CBSEncryption()



from typing import Any

from checkov.arm.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class AppServicePublicAccessDisabled(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that Azure Web App public network access is disabled"
        id = "CKV_AZURE_222"
        supported_resources = [
            "Microsoft.Web/sites",
            "Microsoft.Web/sites/slots",
            "Microsoft.Web/sites/config"
        ]
        categories = [CheckCategories.NETWORKING,]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "properties/publicNetworkAccess"

    def get_expected_value(self) -> Any:
        return "Disabled"


check = AppServicePublicAccessDisabled()



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories, CheckResult


class RDSInstancePerformanceInsights(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that RDS instances have performance insights enabled"
        id = "CKV_AWS_353"
        supported_resources = ('aws_rds_cluster_instance', 'aws_db_instance')
        categories = (CheckCategories.LOGGING,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        # Performance Insights is not available  for MariaDB and MySQL using certain classes: https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights.Overview.Engines.html
        if conf.get("engine") in (["mariadb"], ["mysql"], ["aws_rds_cluster.default.engine"]):
            if conf.get("instance_class") in (["db.t2.micro"], ["db.t2.small"], ["db.t3.micro"], ["db.t3.small"],
                                              ["db.t4g.micro"], ["db.t4g.small"]):
                return CheckResult.UNKNOWN
        # Performance Insights is not supported for DB2: https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.RDS_Fea_Regions_DB-eng.Feature.PerformanceInsights.html
        if conf.get("engine") in (["db2-se"], ["db2-ae"]):
            return CheckResult.UNKNOWN
        return super().scan_resource_conf(conf)

    def get_inspected_key(self) -> str:
        return 'performance_insights_enabled'


check = RDSInstancePerformanceInsights()



from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class StorageLocalUsers(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Avoid the use of local users for Azure Storage unless necessary"
        id = "CKV_AZURE_244"
        supported_resources = ('azurerm_storage_account',)
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return 'local_user_enabled'

    def get_expected_value(self) -> bool:
        return False


check = StorageLocalUsers()
